pytest-growl
------------
 :Author: Anthony Long
 :Date: 2/11/2011
 :Version: 0.1

This plugin sends growl notifications when your test session begins and ends, along with result counts in a short format.

.. image:: http://files.droplr.com/files/138477723/xvjZ.Screen%20shot%202011-02-11%20at%2015%3A06%3A58.png

The theme displayed in the image is included if you wish to use it.


Installation
____________

1) Install
2) py.test --growl
